@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2020 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -26,28 +26,20 @@ extern "C" {
   Define declarations.
 */
 #define MagickPackageName "ImageMagick"
-#define MagickCopyright  "© 1999-2020 ImageMagick Studio LLC"
-#define MagickLibVersion  0x69A
-#define MagickLibVersionText  "6.9.10"
-#define MagickLibVersionNumber  6,0,0
-#define MagickLibAddendum  "-86"
-#define MagickLibInterface  6
-#define MagickLibMinInterface  6
-#if defined(_WINDOWS)
-#  if defined(_WIN64)
-#    define MagickPlatform "x64"
-#  else
-#    define MagickPlatform "x86"
-#  endif
-#else
+#define MagickCopyright  "(C) 1999-2021 ImageMagick Studio LLC"
+#define MagickLibVersion  0x69C
+#define MagickLibVersionText  "6.9.12"
+#define MagickLibVersionNumber  7,0,0
+#define MagickLibAddendum  "-2"
+#define MagickLibInterface  7
+#define MagickLibMinInterface  7
 #define MagickPlatform  "powerpc64"
-#endif
-#define MagickppLibVersionText  "6.9.10"
-#define MagickppLibVersionNumber  8:0:0
-#define MagickppLibAddendum  "-86"
-#define MagickppLibInterface  8
-#define MagickppLibMinInterface  8
-#define MagickReleaseDate  "2020-10-01"
+#define MagickppLibVersionText  "6.9.12"
+#define MagickppLibVersionNumber  9:0:0
+#define MagickppLibAddendum  "-2"
+#define MagickppLibInterface  9
+#define MagickppLibMinInterface  9
+#define MagickReleaseDate  ""
 #define MagickHomeURL  "file:///usr/local/share/doc/ImageMagick/index.html"
 #define MagickAuthoritativeLicense  \
   "https://imagemagick.org/script/license.php"
