@@ -1,11 +1,11 @@
 /*
-  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
-  You may not use this file except in compliance with the License.
+  You may not use this file except in compliance with the License.  You may
   obtain a copy of the License at
   
-    http://www.imagemagick.org/script/license.php
+    https://imagemagick.org/script/license.php
   
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
@@ -15,22 +15,23 @@
 
   MagickCore X11 widget methods.
 */
-#ifndef _MAGICKCORE_WIDGET_H
-#define _MAGICKCORE_WIDGET_H
+#ifndef MAGICKCORE_WIDGET_H
+#define MAGICKCORE_WIDGET_H
+
+#if defined(MAGICKCORE_X11_DELEGATE)
+#include "magick/xwindow-private.h"
+#endif
 
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
 #endif
 
 #if defined(MAGICKCORE_X11_DELEGATE)
-
-#include "magick/xwindow-private.h"
-
 extern MagickExport int
-  XCommandWidget(Display *,XWindows *,const char **,XEvent *),
+  XCommandWidget(Display *,XWindows *,const char *const *,XEvent *),
   XConfirmWidget(Display *,XWindows *,const char *,const char *),
   XDialogWidget(Display *,XWindows *,const char *,const char *,char *),
-  XMenuWidget(Display *,XWindows *,const char *,const char **,char *);
+  XMenuWidget(Display *,XWindows *,const char *,const char *const *,char *);
 
 extern MagickExport MagickBooleanType
   XPreferencesWidget(Display *,XResourceInfo *,XWindows *);
@@ -41,7 +42,7 @@ extern MagickExport void
   XFileBrowserWidget(Display *,XWindows *,const char *,char *),
   XFontBrowserWidget(Display *,XWindows *,const char *,char *),
   XInfoWidget(Display *,XWindows *,const char *),
-  XListBrowserWidget(Display *,XWindows *,XWindowInfo *,const char **,
+  XListBrowserWidget(Display *,XWindows *,XWindowInfo *,const char *const *,
     const char *,const char *,char *),
   XNoticeWidget(Display *,XWindows *,const char *,const char *),
   XProgressMonitorWidget(Display *,XWindows *,const char *,
@@ -49,6 +50,26 @@ extern MagickExport void
   XTextViewWidget(Display *,const XResourceInfo *,XWindows *,
     const MagickBooleanType,const char *,const char **);
 
+static inline void XTextViewHelp(Display *display,
+  const XResourceInfo *resource_info,XWindows *windows,
+  const MagickBooleanType mono,const char *title,const char *help)
+{
+  char
+    **help_list;
+
+  ssize_t
+    i;
+
+  help_list=StringToList(help);
+  if (help_list == (char **) NULL)
+    return;
+  XTextViewWidget(display,resource_info,windows,mono,title,(const char **)
+    help_list);
+  for (i=0; help_list[i] != (char *) NULL; i++)
+    help_list[i]=DestroyString(help_list[i]);
+  help_list=(char **) RelinquishMagickMemory(help_list);
+}
+
 #endif
 
 #if defined(__cplusplus) || defined(c_plusplus)
